# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: UserTwoStepVerificationGetPasswordDetail.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='UserTwoStepVerificationGetPasswordDetail.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n.UserTwoStepVerificationGetPasswordDetail.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"K\n(UserTwoStepVerificationGetPasswordDetail\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\"\xd8\x01\n0UserTwoStepVerificationGetPasswordDetailResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x14\n\x0cquestion_one\x18\x02 \x01(\t\x12\x14\n\x0cquestion_two\x18\x03 \x01(\t\x12\x0c\n\x04hint\x18\x04 \x01(\t\x12$\n\x1chas_confirmed_recovery_email\x18\x05 \x01(\x08\x12!\n\x19unconfirmed_email_pattern\x18\x06 \x01(\tB?\n\x0enet.iGap.protoB-ProtoUserTwoStepVerificationGetPasswordDetailb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_USERTWOSTEPVERIFICATIONGETPASSWORDDETAIL = _descriptor.Descriptor(
  name='UserTwoStepVerificationGetPasswordDetail',
  full_name='proto.UserTwoStepVerificationGetPasswordDetail',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.UserTwoStepVerificationGetPasswordDetail.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=88,
  serialized_end=163,
)


_USERTWOSTEPVERIFICATIONGETPASSWORDDETAILRESPONSE = _descriptor.Descriptor(
  name='UserTwoStepVerificationGetPasswordDetailResponse',
  full_name='proto.UserTwoStepVerificationGetPasswordDetailResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.UserTwoStepVerificationGetPasswordDetailResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='question_one', full_name='proto.UserTwoStepVerificationGetPasswordDetailResponse.question_one', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='question_two', full_name='proto.UserTwoStepVerificationGetPasswordDetailResponse.question_two', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hint', full_name='proto.UserTwoStepVerificationGetPasswordDetailResponse.hint', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='has_confirmed_recovery_email', full_name='proto.UserTwoStepVerificationGetPasswordDetailResponse.has_confirmed_recovery_email', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='unconfirmed_email_pattern', full_name='proto.UserTwoStepVerificationGetPasswordDetailResponse.unconfirmed_email_pattern', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=166,
  serialized_end=382,
)

_USERTWOSTEPVERIFICATIONGETPASSWORDDETAIL.fields_by_name['request'].message_type = Request__pb2._REQUEST
_USERTWOSTEPVERIFICATIONGETPASSWORDDETAILRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
DESCRIPTOR.message_types_by_name['UserTwoStepVerificationGetPasswordDetail'] = _USERTWOSTEPVERIFICATIONGETPASSWORDDETAIL
DESCRIPTOR.message_types_by_name['UserTwoStepVerificationGetPasswordDetailResponse'] = _USERTWOSTEPVERIFICATIONGETPASSWORDDETAILRESPONSE

UserTwoStepVerificationGetPasswordDetail = _reflection.GeneratedProtocolMessageType('UserTwoStepVerificationGetPasswordDetail', (_message.Message,), dict(
  DESCRIPTOR = _USERTWOSTEPVERIFICATIONGETPASSWORDDETAIL,
  __module__ = 'UserTwoStepVerificationGetPasswordDetail_pb2'
  # @@protoc_insertion_point(class_scope:proto.UserTwoStepVerificationGetPasswordDetail)
  ))
_sym_db.RegisterMessage(UserTwoStepVerificationGetPasswordDetail)

UserTwoStepVerificationGetPasswordDetailResponse = _reflection.GeneratedProtocolMessageType('UserTwoStepVerificationGetPasswordDetailResponse', (_message.Message,), dict(
  DESCRIPTOR = _USERTWOSTEPVERIFICATIONGETPASSWORDDETAILRESPONSE,
  __module__ = 'UserTwoStepVerificationGetPasswordDetail_pb2'
  # @@protoc_insertion_point(class_scope:proto.UserTwoStepVerificationGetPasswordDetailResponse)
  ))
_sym_db.RegisterMessage(UserTwoStepVerificationGetPasswordDetailResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB-ProtoUserTwoStepVerificationGetPasswordDetail'))
# @@protoc_insertion_point(module_scope)



from .message import Message
from typing import Any, Callable
from aiohttp import web
from .filters import Filter
from ighap_bot.proto import (
    ChatSendMessage_pb2, ChatEditMessage_pb2, ChatUpdateStatus_pb2, GroupKickMember_pb2, GroupSendMessage_pb2,
    ChatGetRoom_pb2, GroupPinMessage_pb2, GroupEditMessage_pb2, FileUploadOption_pb2, FileUploadInit_pb2,
    FileUpload_pb2, FileUploadStatus_pb2, GroupChangeMemberRights_pb2, GroupUpdateStatus_pb2, GroupDeleteMessage_pb2,
    ChatDeleteMessage_pb2, GroupEdit_pb2, ChannelSendMessage_pb2, ChannelEditMessage_pb2, ChannelDeleteMessage_pb2)
from google.protobuf import json_format
import random, json, aiohttp, os, asyncio, uuid, mimetypes
from collections import deque
from typing import Tuple
from PIL import Image

last_message_ids = deque(maxlen=20)

PRIVATE_ACTION_IDS = [str(i) for i in range(200, 210)] + [str(i) for i in range(30200, 30210)]
GROUP_ACTION_IDS = [str(i) for i in range(300, 329)] + [str(i) for i in range(30300, 30329)]
CHANNEL_ACTION_IDS = [str(i) for i in range(400, 427)] + [str(i) for i in range(30400, 30427)]

class BotClient:
    def __init__(self, token):
        self.token = token
        self.headers = {
            "Authorization": f"Bearer {self.token}",
            "Content-Type": "application/octet-stream"
        }
        self.data: dict = {}
        self.roomMessage = {}
        self.handlers = {}              # لیست هندلرها
        self.message_wrapper = None     # پیام فعلی
        self.propagationStopped = True

    async def handle_post(self, request):
        # گرفتن داده‌ی خام
        raw_data = await request.read()
        print(f"{request.method} {request.path} {request.query}")
        
        action_id_map = {
            "30201": ChatSendMessage_pb2.ChatSendMessageResponse,
            "30202": ChatUpdateStatus_pb2.ChatUpdateStatusResponse,
            "30307": GroupKickMember_pb2.GroupKickMemberResponse,
            "30310": GroupSendMessage_pb2.GroupSendMessageResponse,
            "30311": GroupUpdateStatus_pb2.GroupUpdateStatusResponse,
            "30327": GroupChangeMemberRights_pb2.GroupChangeMemberRightsResponse,
            "30410": ChannelSendMessage_pb2.ChannelSendMessageResponse
        }

        self.action_id = request.query.get("actionId")
        if self.action_id in action_id_map:
            self.data = self.decode_message(raw_data, action_id_map[self.action_id])
            # if self.action_id == "30311":print(f"response: {self.data}")

        # ذخیره برای استفاده در هندلرها
        self.roomMessage = self.data.get("roomMessage", {})
        self.data["actionId"] = self.action_id # اضافه کردن action_id به update 
        self.message_wrapper = Message(self, self.data)
        message_id = self.roomMessage.get("messageId")

        # print(last_message_ids)
        if not message_id in last_message_ids:
            last_message_ids.append(message_id)
            await self._dispatch_handlers()
            
        return web.Response(text="OK")

    def on_message(self, *filters) -> Callable:
        """
        Decorator برای ثبت هندلر پیام با فیلترهای اختیاری.
        تابعی که با این decorator تزئین می‌شود باید یک آرگومان از نوع Message دریافت کند.
        """
        def decorator(func: Callable):
            filter_key = str(uuid.uuid4())
            if filter_key not in self.handlers:
                self.handlers[filter_key] = []
            # ذخیره‌ی هندلر همراه با فیلترها و نوع
            self.handlers[filter_key].append({
                "filters": filters,
                "callback": func,
                "type": "message"
            })
            return func
        return decorator
    
    def on_member_rights_change(self) -> Callable:
        """
        Decorator برای ثبت هندلر تغییر دسترسی اعضا.
        تابعی که با این decorator تزئین می‌شود باید یک آرگومان از نوع Update یا MemberRights دریافت کند.
        """
        def decorator(func: Callable):
            filter_key = str(uuid.uuid4())
            if filter_key not in self.handlers:
                self.handlers[filter_key] = []
            # ذخیره‌ی هندلر همراه با نوع
            self.handlers[filter_key].append({
                "filters": (),   # اینجا معمولاً فیلتر خاصی نداری
                "callback": func,
                "type": "member_rights"
            })
            return func
        return decorator
    
    def on_message_status_update(self, *filters) -> Callable:
        """
        Decorator برای ثبت هندلر تغییر وضعیت پیام‌های گروه.
        تابعی که با این decorator تزئین می‌شود باید یک آرگومان
        از نوع UpdateStatus_pb2.UpdateStatusResponse دریافت کند.
        """
        def decorator(func: Callable):
            filter_key = str(uuid.uuid4())
            if filter_key not in self.handlers:
                self.handlers[filter_key] = []
            # ذخیره‌ی هندلر همراه با نوع
            self.handlers[filter_key].append({
                "filters": filters,
                "callback": func,
                "type": "update_status"
            })
            return func
        return decorator

    async def _dispatch_handlers(self):
        for handler_list in self.handlers.values():
            for handler in handler_list:
                filters = handler.get("filters", [])
                callback = handler["callback"]
                handler_type = handler.get("type")
                # بررسی نوع هندلر
                if handler_type == "message":
                    if self.roomMessage and await self._match_filters(self.message_wrapper, filters):
                        await callback(self.message_wrapper)
                        if self.propagationStopped: return
                elif handler_type == "member_rights":
                    if self.data.get("permission"):
                        await callback(self.message_wrapper)
                        if self.propagationStopped:
                            return
                elif handler_type == "update_status" and self.data.get("updaterAuthorHash") and await self._match_filters(self.message_wrapper, filters):
                    await callback(self.message_wrapper)
                    if self.propagationStopped: return

    async def _match_filters(self, message, filters: Tuple[Filter, ...]) -> bool:
        for f in filters:
            result = await f.check(message)
            if not result:  # اگر یکی از فیلترها False بده، هندلر اجرا نمی‌شه
                return False
        return True

    def run(self, path_webhook="/webhook", host="localhost", port=8000):
        """راه‌اندازی سرور aiohttp"""
        app = web.Application()
        app.router.add_post(path_webhook, self.handle_post)
        web.run_app(app, host=host, port=port)

    def stop_propagation(self):
        self.propagationStopped = True
    
    def generate_random_id(self, length=19):
        return int(''.join(str(random.randint(0, 9)) for _ in range(length)))

    def decode_message(self, binary_data: bytes, proto_cls):
        """دیکد کردن پاسخ پروتو و تبدیل به dict"""
        response = proto_cls()
        response.ParseFromString(binary_data)

        # تبدیل به dict
        decode_json = json_format.MessageToJson(response)
        return json.loads(decode_json)

    def build_proto_data(self, proto_cls, **fields) -> bytes:
        """
        ساختن پروتو و تبدیل به باینری
        proto_cls: کلاس پروتو (مثلاً ChatSendMessage_pb2.ChatSendMessage)
        fields: فیلدهای لازم برای پر کردن پروتو
        """
        message = proto_cls()
        for key, value in fields.items():
            setattr(message, key, value)
        return message.SerializeToString()
    
    async def send_message(self, room_id, text, reply_to_message_id = None, target_type=None):
        fields = {
            "message": text,
            "room_id": int(room_id),
            "random_id": self.generate_random_id(),
            "message_type": 0
        }
        if reply_to_message_id is not None:
            fields["reply_to"] = int(reply_to_message_id)

        if (self.action_id and self.action_id in PRIVATE_ACTION_IDS) or (target_type and target_type == "private"):
            data = self.build_proto_data(ChatSendMessage_pb2.ChatSendMessage, **fields)
            return await self.execute_action(201, data, ChatSendMessage_pb2.ChatSendMessageResponse)
        elif (self.action_id and self.action_id in GROUP_ACTION_IDS) or (target_type and target_type == "group"):
            data = self.build_proto_data(GroupSendMessage_pb2.GroupSendMessage, **fields)
            return await self.execute_action(310, data, GroupSendMessage_pb2.GroupSendMessageResponse)
        elif (self.action_id and self.action_id in CHANNEL_ACTION_IDS) or (target_type and target_type == "channel"):
            data = self.build_proto_data(ChannelSendMessage_pb2.ChannelSendMessage, **fields)
            return await self.execute_action(410, data, ChannelSendMessage_pb2.ChannelSendMessageResponse)
        else:
            raise ValueError(f'Invalid target_type "{target_type}". Must be one of ("private", "group", "channel").')
    
    async def edit_message(self, room_id: int, message_id: int, new_text: str, target_type=None):
        fields = {
            "room_id": int(room_id),
            "message_id": int(message_id),
            "message": new_text
        }
        if (self.action_id and self.action_id in PRIVATE_ACTION_IDS) or (target_type and target_type == "private"):
            data = self.build_proto_data(ChatEditMessage_pb2.ChatEditMessage, **fields)
            return await self.execute_action(203, data, ChatEditMessage_pb2.ChatEditMessageResponse)
        elif (self.action_id and self.action_id in GROUP_ACTION_IDS) or (target_type and target_type == "group"):
            data = self.build_proto_data(GroupEditMessage_pb2.GroupEditMessage, **fields)
            return await self.execute_action(325, data, GroupEditMessage_pb2.GroupEditMessageResponse)
        elif (self.action_id and self.action_id in GROUP_ACTION_IDS) or (target_type and target_type == "channel"):
            data = self.build_proto_data(ChannelEditMessage_pb2.ChannelEditMessage, **fields)
            return await self.execute_action(425, data, ChannelEditMessage_pb2.ChannelEditMessageResponse)
        else:
            raise ValueError(f'Invalid target_type "{target_type}". Must be one of ("private", "group", "channel").')
    
    async def delete_message(self, room_id: int, message_id: int, delete_type="Global", target_type=None):
        fields = {
            "room_id": int(room_id),
            "message_id": int(message_id),
        }
        if (self.action_id and self.action_id in PRIVATE_ACTION_IDS) or (target_type and target_type == "private"):
            fields["both"] = True if delete_type == "Global" else False
            data = self.build_proto_data(ChatDeleteMessage_pb2.ChatDeleteMessage, **fields)
            return await self.execute_action(204, data, ChatDeleteMessage_pb2.ChatDeleteMessageResponse)
        elif (self.action_id and self.action_id in GROUP_ACTION_IDS) or (target_type and target_type == "group"):
            data = self.build_proto_data(GroupDeleteMessage_pb2.GroupDeleteMessage, **fields)
            return await self.execute_action(320, data, GroupDeleteMessage_pb2.GroupDeleteMessageResponse)
        elif (self.action_id and self.action_id in GROUP_ACTION_IDS) or (target_type and target_type == "channel"):
            data = self.build_proto_data(ChatDeleteMessage_pb2.ChatDeleteMessage, **fields)
            return await self.execute_action(411, data, ChannelDeleteMessage_pb2.ChannelDeleteMessageResponse)
        else:
            raise ValueError(f'Invalid target_type "{target_type}". Must be one of ("private", "group", "channel").')
        
    async def ban_member(self, room_id: int, member_id: int, target_type=None):
        fields = {
            "room_id": int(room_id),
            "member_id": int(member_id)
        }
        if (self.action_id and self.action_id in GROUP_ACTION_IDS) or (target_type and target_type == "group"):
            data = self.build_proto_data(GroupKickMember_pb2.GroupKickMember, **fields)
            return await self.execute_action(320, data, GroupKickMember_pb2.GroupKickMemberResponse)
        else:
            raise ValueError(f'Invalid target_type "{target_type}". Must be one of ("group", "channel").')

    def generate_thumbnail(self, file_path: str, size: tuple[int, int]) -> str:
        """
        ساخت thumbnail از تصویر اصلی با اندازه‌ی مشخص.
        """
        with Image.open(file_path) as img:
            if img.mode in ("RGBA", "P"):
                img = img.convert("RGB")

            img.thumbnail(size)

            base, ext = os.path.splitext(file_path)
            thumb_path = f"{base}_thumb.jpg"

            img.save(thumb_path, format="JPEG")

        return thumb_path

    async def send_photo(self, room_id, file_path, caption=None, reply_to_message_id=None, target_type=None):

        token = await self.upload_file_to_ighap(file_path)
        mime = mimetypes.guess_type(file_path)[0] or "image/jpeg"

        with Image.open(file_path) as img:
            width, height = img.size

        large_thumb_path = self.generate_thumbnail(file_path, (350, 824))
        large_token = await self.upload_file_to_ighap(large_thumb_path)
        large_size = os.path.getsize(large_thumb_path)

        small_thumb_path = self.generate_thumbnail(file_path, (100, 235))
        small_token = await self.upload_file_to_ighap(small_thumb_path)
        small_size = os.path.getsize(small_thumb_path)

        attachment = {
            "token": token,
            "size": os.path.getsize(file_path),
            "name": os.path.basename(file_path),
            "mime": mime,
            "width": width,
            "height": height,
            "cacheId": token,
            "largeThumbnail": {
                "size": large_size,
                "width": 350,
                "height": 824,
                "cacheId": f"{token}LT",
                "name": os.path.basename(large_thumb_path),
                "mime": "image/jpeg"
            },
            "smallThumbnail": {
                "size": small_size,
                "width": 100,
                "height": 235,
                "cacheId": f"{token}ST",
                "name": os.path.basename(small_thumb_path),
                "mime": "image/jpeg"
            }
        }

        fields = {
            "room_id": int(room_id),
            "random_id": self.generate_random_id(),
            "attachment": json.dumps(attachment),
            "message_type": 2 if caption else 1
        }

        if reply_to_message_id is not None:
            fields["reply_to"] = int(reply_to_message_id)
        if caption is not None:
            fields["message"] = caption

        if (self.action_id and self.action_id in PRIVATE_ACTION_IDS) or (target_type == "private"):
            data = self.build_proto_data(ChatSendMessage_pb2.ChatSendMessage, **fields)
            return await self.execute_action(201, data, ChatSendMessage_pb2.ChatSendMessageResponse)
        elif (self.action_id and self.action_id in GROUP_ACTION_IDS) or (target_type == "group"):
            data = self.build_proto_data(GroupSendMessage_pb2.GroupSendMessage, **fields)
            return await self.execute_action(310, data, GroupSendMessage_pb2.GroupSendMessageResponse)
        else:
            raise ValueError(f'Invalid target_type \"{target_type}\". Must be one of (\"private\", \"group\", \"channel\").')
    
    async def send_message_private(self, room_id, text, reply_to_message_id = None):
        return await self.send_message(room_id=room_id, text=text, reply_to_message_id=reply_to_message_id, target_type="private")

    async def edit_message_private(self, room_id: int, message_id: int, new_text: str):
        return await self.edit_message(room_id=room_id, message_id=message_id, new_text=new_text, target_type="private")

    async def delete_message_private(self, room_id: int, message_id: int, delete_type = "Global"):
        return await self.delete_message(room_id=room_id, message_id=message_id, delete_type=delete_type, target_type="private")

    async def get_room_private(self, room_id: int):
        """
        ⚠️ وضعیت: این متد در نسخه‌ی فعلی iGap Bot API غیرفعال است.
        سرور در پاسخ به درخواست، خطای PAGE_NOT_FOUND برمی‌گرداند.
        """
        fields = {
            "peer_id": int(room_id)
        }
        data = self.build_proto_data(ChatGetRoom_pb2.ChatGetRoom, **fields)
        return await self.execute_action(200, data, ChatGetRoom_pb2.ChatGetRoomResponse)

    async def send_photo_private(self, room_id, file_path, caption=None, reply_to_message_id=None):
        return await self.send_photo(room_id, file_path, caption, reply_to_message_id, "private")

    async def send_message_group(self, room_id, text, reply_to_message_id = None):
        return await self.send_message(room_id=room_id, text=text, reply_to_message_id=reply_to_message_id, target_type="group")

    async def edit_message_group(self, room_id: int, message_id: int, new_text: str):
        return await self.edit_message(room_id=room_id, message_id=message_id, new_text=new_text, target_type="group")

    async def delete_message_group(self, room_id: int, message_id: int):
        return await self.delete_message(room_id=room_id, message_id=message_id, target_type="group")

    async def pin_message_group(self, room_id: int, message_id: int):
        """
        ⚠️ وضعیت: این متد در نسخه‌ی فعلی iGap Bot API غیرفعال است.
        سرور در پاسخ به درخواست، خطای PAGE_NOT_FOUND برمی‌گرداند.
        """
        fields = {
            "room_id": int(room_id),
            "message_id": int(message_id)
        }

        data = self.build_proto_data(GroupPinMessage_pb2.GroupPinMessage, **fields)
        action_id = 326
        return await self.execute_action(action_id, data, GroupPinMessage_pb2.GroupPinMessageResponse)

    async def send_photo_group(self, room_id, file_path, caption = None, reply_to_message_id = None):
        return await self.send_photo(room_id, file_path, caption, reply_to_message_id, "group")
    
    async def ban_member_group(self, room_id, member_id):
        """
        ⚠️ توجه: این متد در نسخه‌ی فعلی iGap Bot API غیرفعال است.
        سرور در پاسخ به درخواست، خطای PAGE_NOT_FOUND برمی‌گرداند.
        """
        return await self.ban_member(room_id, member_id, "group")
    
    async def edit_group_info(self, room_id, group_name=None, description=None):
        """
        ⚠️ وضعیت: این متد در نسخه‌ی فعلی iGap Bot API غیرفعال است.
        سرور در پاسخ به درخواست، خطای PAGE_NOT_FOUND برمی‌گرداند.
        """
        fields = {"room_id": int(room_id)}
        if group_name is not None: fields["name"] = group_name
        if description is not None: fields["description"] = description
        data = self.build_proto_data(GroupEdit_pb2.GroupEdit, **fields)
        return await self.execute_action(30305, data, GroupEdit_pb2.GroupEditResponse)
    
    async def send_message_channel(self, room_id, text, reply_to_message_id = None):
        return await self.send_message(room_id, text, reply_to_message_id, "channel")
    
    async def edit_message_channel(self, room_id: int, message_id: int, new_text: str):
        return await self.edit_message(room_id=room_id, message_id=message_id, new_text=new_text, target_type="channel")
    
    async def delete_message_channel(self, message_id: int=None):
        return await self.delete_message(self.room_id, message_id or self.room_message.message_id, target_type="channel")

    async def upload_file_to_ighap(self, path):
        size = os.path.getsize(path)
        fields = {"size": size}
        data = self.build_proto_data(FileUploadOption_pb2.FileUploadOption, **fields)
        response = await self.execute_action(700, data, FileUploadOption_pb2.FileUploadOptionResponse)
        print("FileUploadOption_pb2: ", response)

        # مرحله دوم: FileUploadInit (با first/last bytes)
        with open(path, "rb") as f:
            first_bytes = f.read(1024)  # یا مقدار درست از FileUploadOptionResponse
            f.seek(size - 1024)
            last_bytes = f.read(1024)

        init_fields = {
            "size": size,
            "file_name": os.path.basename(path),
            "first_bytes": first_bytes,
            "last_bytes": last_bytes
        }
        init_data = self.build_proto_data(FileUploadInit_pb2.FileUploadInit, **init_fields)
        resp_init = await self.execute_action(701, init_data, FileUploadInit_pb2.FileUploadInitResponse)

        token = resp_init.get("token")
        offset = resp_init.get("offset", 0)
        limit = resp_init.get("limit", 4096)  # اگر خالی بود، یک مقدار پیش‌فرض بذار
        progress = resp_init.get("progress", 0)

        # مرحله سوم: FileUpload (chunk upload)
        with open(path, "rb") as f:
            while progress < 100:
                f.seek(offset)
                chunk = f.read(limit)

                upload_fields = {
                    "token": token,
                    "offset": offset,
                    "bytes": chunk
                }
                upload_data = self.build_proto_data(FileUpload_pb2.FileUpload, **upload_fields)
                resp_upload = await self.execute_action(702, upload_data, FileUpload_pb2.FileUploadResponse)
                print(f"resp_upload: {resp_upload}")

                progress = resp_upload.get("progress") or progress
                offset = resp_upload.get("nextOffset") or (offset + limit)
                limit = resp_upload.get("nextLimit") or limit

        # مرحله چهارم: FileUploadStatus (با retry)
        status_fields = {"token": token}
        status_data = self.build_proto_data(FileUploadStatus_pb2.FileUploadStatus, **status_fields)

        for attempt in range(5):
            resp_status = await self.execute_action(703, status_data, FileUploadStatus_pb2.FileUploadStatusResponse)
            print(f"resp_status: {resp_status}")
            if resp_status.get("status") == "PROCESSED":
                return token
            await asyncio.sleep(1)

        raise Exception("Upload failed or still processing after retries")

    async def execute_action(
        self,
        action_id: int,
        payload: bytes,
        decode_type: Callable[[bytes], Any] = None
    ):
        url = f"https://api.igap.net/botland/v1/api?actionId={action_id}"

        async with aiohttp.ClientSession() as session:
            async with session.post(url, data=payload, headers=self.headers) as resp:
                resp_bytes = await resp.read()

                if decode_type:
                    try: return self.decode_message(resp_bytes, decode_type)
                    except Exception as e:
                        error_info = {
                            "Error decode": str(e),
                            "bytes": resp_bytes if resp_bytes else None
                        }
                        return error_info
                else:
                    return resp_bytes




# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: InfoTime.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='InfoTime.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x0eInfoTime.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"+\n\x08InfoTime\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\"H\n\x10InfoTimeResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x11\n\ttimestamp\x18\x02 \x01(\rB\x1f\n\x0enet.iGap.protoB\rProtoInfoTimeb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_INFOTIME = _descriptor.Descriptor(
  name='InfoTime',
  full_name='proto.InfoTime',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.InfoTime.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=56,
  serialized_end=99,
)


_INFOTIMERESPONSE = _descriptor.Descriptor(
  name='InfoTimeResponse',
  full_name='proto.InfoTimeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.InfoTimeResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='proto.InfoTimeResponse.timestamp', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=101,
  serialized_end=173,
)

_INFOTIME.fields_by_name['request'].message_type = Request__pb2._REQUEST
_INFOTIMERESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
DESCRIPTOR.message_types_by_name['InfoTime'] = _INFOTIME
DESCRIPTOR.message_types_by_name['InfoTimeResponse'] = _INFOTIMERESPONSE

InfoTime = _reflection.GeneratedProtocolMessageType('InfoTime', (_message.Message,), dict(
  DESCRIPTOR = _INFOTIME,
  __module__ = 'InfoTime_pb2'
  # @@protoc_insertion_point(class_scope:proto.InfoTime)
  ))
_sym_db.RegisterMessage(InfoTime)

InfoTimeResponse = _reflection.GeneratedProtocolMessageType('InfoTimeResponse', (_message.Message,), dict(
  DESCRIPTOR = _INFOTIMERESPONSE,
  __module__ = 'InfoTime_pb2'
  # @@protoc_insertion_point(class_scope:proto.InfoTimeResponse)
  ))
_sym_db.RegisterMessage(InfoTimeResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\rProtoInfoTime'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: InfoWallpaper.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2
from ighap_bot.proto import Global_pb2 as Global__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='InfoWallpaper.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x13InfoWallpaper.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\x1a\x0cGlobal.proto\"\xdf\x01\n\rInfoWallpaper\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12%\n\x03\x66it\x18\x02 \x01(\x0e\x32\x18.proto.InfoWallpaper.Fit\x12\'\n\x04type\x18\x03 \x01(\x0e\x32\x19.proto.InfoWallpaper.Type\")\n\x03\x46it\x12\t\n\x05PHONE\x10\x00\x12\n\n\x06TABLET\x10\x01\x12\x0b\n\x07\x44\x45SKTOP\x10\x02\"2\n\x04Type\x12\x13\n\x0f\x43HAT_BACKGROUND\x10\x00\x12\x15\n\x11PROFILE_WALLPAPER\x10\x01\"_\n\x15InfoWallpaperResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12#\n\twallpaper\x18\x02 \x03(\x0b\x32\x10.proto.WallpaperB$\n\x0enet.iGap.protoB\x12ProtoInfoWallpaperb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,Global__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_INFOWALLPAPER_FIT = _descriptor.EnumDescriptor(
  name='Fit',
  full_name='proto.InfoWallpaper.Fit',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PHONE', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TABLET', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DESKTOP', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=206,
  serialized_end=247,
)
_sym_db.RegisterEnumDescriptor(_INFOWALLPAPER_FIT)

_INFOWALLPAPER_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='proto.InfoWallpaper.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CHAT_BACKGROUND', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROFILE_WALLPAPER', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=249,
  serialized_end=299,
)
_sym_db.RegisterEnumDescriptor(_INFOWALLPAPER_TYPE)


_INFOWALLPAPER = _descriptor.Descriptor(
  name='InfoWallpaper',
  full_name='proto.InfoWallpaper',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.InfoWallpaper.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fit', full_name='proto.InfoWallpaper.fit', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='proto.InfoWallpaper.type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _INFOWALLPAPER_FIT,
    _INFOWALLPAPER_TYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=76,
  serialized_end=299,
)


_INFOWALLPAPERRESPONSE = _descriptor.Descriptor(
  name='InfoWallpaperResponse',
  full_name='proto.InfoWallpaperResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.InfoWallpaperResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='wallpaper', full_name='proto.InfoWallpaperResponse.wallpaper', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=301,
  serialized_end=396,
)

_INFOWALLPAPER.fields_by_name['request'].message_type = Request__pb2._REQUEST
_INFOWALLPAPER.fields_by_name['fit'].enum_type = _INFOWALLPAPER_FIT
_INFOWALLPAPER.fields_by_name['type'].enum_type = _INFOWALLPAPER_TYPE
_INFOWALLPAPER_FIT.containing_type = _INFOWALLPAPER
_INFOWALLPAPER_TYPE.containing_type = _INFOWALLPAPER
_INFOWALLPAPERRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_INFOWALLPAPERRESPONSE.fields_by_name['wallpaper'].message_type = Global__pb2._WALLPAPER
DESCRIPTOR.message_types_by_name['InfoWallpaper'] = _INFOWALLPAPER
DESCRIPTOR.message_types_by_name['InfoWallpaperResponse'] = _INFOWALLPAPERRESPONSE

InfoWallpaper = _reflection.GeneratedProtocolMessageType('InfoWallpaper', (_message.Message,), dict(
  DESCRIPTOR = _INFOWALLPAPER,
  __module__ = 'InfoWallpaper_pb2'
  # @@protoc_insertion_point(class_scope:proto.InfoWallpaper)
  ))
_sym_db.RegisterMessage(InfoWallpaper)

InfoWallpaperResponse = _reflection.GeneratedProtocolMessageType('InfoWallpaperResponse', (_message.Message,), dict(
  DESCRIPTOR = _INFOWALLPAPERRESPONSE,
  __module__ = 'InfoWallpaper_pb2'
  # @@protoc_insertion_point(class_scope:proto.InfoWallpaperResponse)
  ))
_sym_db.RegisterMessage(InfoWallpaperResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\022ProtoInfoWallpaper'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ChannelGetMemberList.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2
from ighap_bot.proto import Global_pb2 as Global__pb2
from ighap_bot.proto import ChannelAddAdmin_pb2 as ChannelAddAdmin__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ChannelGetMemberList.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x1a\x43hannelGetMemberList.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\x1a\x0cGlobal.proto\x1a\x15\x43hannelAddAdmin.proto\"\xe9\x01\n\x14\x43hannelGetMemberList\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x0f\n\x07room_id\x18\x02 \x01(\x04\x12;\n\x0b\x66ilter_role\x18\x03 \x01(\x0e\x32&.proto.ChannelGetMemberList.FilterRole\x12%\n\npagination\x18\x04 \x01(\x0b\x32\x11.proto.Pagination\";\n\nFilterRole\x12\x07\n\x03\x41LL\x10\x00\x12\n\n\x06MEMBER\x10\x01\x12\r\n\tMODERATOR\x10\x02\x12\t\n\x05\x41\x44MIN\x10\x03\"\xf7\x01\n\x1c\x43hannelGetMemberListResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12:\n\x06member\x18\x02 \x03(\x0b\x32*.proto.ChannelGetMemberListResponse.Member\x1ax\n\x06Member\x12\x0e\n\x06userId\x18\x01 \x01(\x04\x12%\n\x04role\x18\x02 \x01(\x0e\x32\x17.proto.ChannelRoom.Role\x12\x37\n\x0b\x61\x64minRights\x18\x03 \x01(\x0b\x32\".proto.ChannelAddAdmin.AdminRightsB+\n\x0enet.iGap.protoB\x19ProtoChannelGetMemberListb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,Global__pb2.DESCRIPTOR,ChannelAddAdmin__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_CHANNELGETMEMBERLIST_FILTERROLE = _descriptor.EnumDescriptor(
  name='FilterRole',
  full_name='proto.ChannelGetMemberList.FilterRole',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ALL', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MEMBER', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODERATOR', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADMIN', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=280,
  serialized_end=339,
)
_sym_db.RegisterEnumDescriptor(_CHANNELGETMEMBERLIST_FILTERROLE)


_CHANNELGETMEMBERLIST = _descriptor.Descriptor(
  name='ChannelGetMemberList',
  full_name='proto.ChannelGetMemberList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.ChannelGetMemberList.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='room_id', full_name='proto.ChannelGetMemberList.room_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='filter_role', full_name='proto.ChannelGetMemberList.filter_role', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='proto.ChannelGetMemberList.pagination', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CHANNELGETMEMBERLIST_FILTERROLE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=106,
  serialized_end=339,
)


_CHANNELGETMEMBERLISTRESPONSE_MEMBER = _descriptor.Descriptor(
  name='Member',
  full_name='proto.ChannelGetMemberListResponse.Member',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='userId', full_name='proto.ChannelGetMemberListResponse.Member.userId', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='role', full_name='proto.ChannelGetMemberListResponse.Member.role', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='adminRights', full_name='proto.ChannelGetMemberListResponse.Member.adminRights', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=469,
  serialized_end=589,
)

_CHANNELGETMEMBERLISTRESPONSE = _descriptor.Descriptor(
  name='ChannelGetMemberListResponse',
  full_name='proto.ChannelGetMemberListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.ChannelGetMemberListResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='member', full_name='proto.ChannelGetMemberListResponse.member', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CHANNELGETMEMBERLISTRESPONSE_MEMBER, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=342,
  serialized_end=589,
)

_CHANNELGETMEMBERLIST.fields_by_name['request'].message_type = Request__pb2._REQUEST
_CHANNELGETMEMBERLIST.fields_by_name['filter_role'].enum_type = _CHANNELGETMEMBERLIST_FILTERROLE
_CHANNELGETMEMBERLIST.fields_by_name['pagination'].message_type = Global__pb2._PAGINATION
_CHANNELGETMEMBERLIST_FILTERROLE.containing_type = _CHANNELGETMEMBERLIST
_CHANNELGETMEMBERLISTRESPONSE_MEMBER.fields_by_name['role'].enum_type = Global__pb2._CHANNELROOM_ROLE
_CHANNELGETMEMBERLISTRESPONSE_MEMBER.fields_by_name['adminRights'].message_type = ChannelAddAdmin__pb2._CHANNELADDADMIN_ADMINRIGHTS
_CHANNELGETMEMBERLISTRESPONSE_MEMBER.containing_type = _CHANNELGETMEMBERLISTRESPONSE
_CHANNELGETMEMBERLISTRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_CHANNELGETMEMBERLISTRESPONSE.fields_by_name['member'].message_type = _CHANNELGETMEMBERLISTRESPONSE_MEMBER
DESCRIPTOR.message_types_by_name['ChannelGetMemberList'] = _CHANNELGETMEMBERLIST
DESCRIPTOR.message_types_by_name['ChannelGetMemberListResponse'] = _CHANNELGETMEMBERLISTRESPONSE

ChannelGetMemberList = _reflection.GeneratedProtocolMessageType('ChannelGetMemberList', (_message.Message,), dict(
  DESCRIPTOR = _CHANNELGETMEMBERLIST,
  __module__ = 'ChannelGetMemberList_pb2'
  # @@protoc_insertion_point(class_scope:proto.ChannelGetMemberList)
  ))
_sym_db.RegisterMessage(ChannelGetMemberList)

ChannelGetMemberListResponse = _reflection.GeneratedProtocolMessageType('ChannelGetMemberListResponse', (_message.Message,), dict(

  Member = _reflection.GeneratedProtocolMessageType('Member', (_message.Message,), dict(
    DESCRIPTOR = _CHANNELGETMEMBERLISTRESPONSE_MEMBER,
    __module__ = 'ChannelGetMemberList_pb2'
    # @@protoc_insertion_point(class_scope:proto.ChannelGetMemberListResponse.Member)
    ))
  ,
  DESCRIPTOR = _CHANNELGETMEMBERLISTRESPONSE,
  __module__ = 'ChannelGetMemberList_pb2'
  # @@protoc_insertion_point(class_scope:proto.ChannelGetMemberListResponse)
  ))
_sym_db.RegisterMessage(ChannelGetMemberListResponse)
_sym_db.RegisterMessage(ChannelGetMemberListResponse.Member)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\031ProtoChannelGetMemberList'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: MplGetCardToCardToken.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='MplGetCardToCardToken.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x1bMplGetCardToCardToken.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"L\n\x15MplGetCardToCardToken\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x12\n\nto_user_id\x18\x02 \x01(\x04\"\x87\x01\n\x1dMplGetCardToCardTokenResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x0e\n\x06status\x18\x02 \x01(\r\x12\r\n\x05token\x18\x03 \x01(\t\x12\x13\n\x0b\x65xpire_time\x18\x04 \x01(\r\x12\x0f\n\x07message\x18\x05 \x01(\tB,\n\x0enet.iGap.protoB\x1aProtoMplGetCardToCardTokenb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_MPLGETCARDTOCARDTOKEN = _descriptor.Descriptor(
  name='MplGetCardToCardToken',
  full_name='proto.MplGetCardToCardToken',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.MplGetCardToCardToken.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='to_user_id', full_name='proto.MplGetCardToCardToken.to_user_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=69,
  serialized_end=145,
)


_MPLGETCARDTOCARDTOKENRESPONSE = _descriptor.Descriptor(
  name='MplGetCardToCardTokenResponse',
  full_name='proto.MplGetCardToCardTokenResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.MplGetCardToCardTokenResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='proto.MplGetCardToCardTokenResponse.status', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='token', full_name='proto.MplGetCardToCardTokenResponse.token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='expire_time', full_name='proto.MplGetCardToCardTokenResponse.expire_time', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='proto.MplGetCardToCardTokenResponse.message', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=148,
  serialized_end=283,
)

_MPLGETCARDTOCARDTOKEN.fields_by_name['request'].message_type = Request__pb2._REQUEST
_MPLGETCARDTOCARDTOKENRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
DESCRIPTOR.message_types_by_name['MplGetCardToCardToken'] = _MPLGETCARDTOCARDTOKEN
DESCRIPTOR.message_types_by_name['MplGetCardToCardTokenResponse'] = _MPLGETCARDTOCARDTOKENRESPONSE

MplGetCardToCardToken = _reflection.GeneratedProtocolMessageType('MplGetCardToCardToken', (_message.Message,), dict(
  DESCRIPTOR = _MPLGETCARDTOCARDTOKEN,
  __module__ = 'MplGetCardToCardToken_pb2'
  # @@protoc_insertion_point(class_scope:proto.MplGetCardToCardToken)
  ))
_sym_db.RegisterMessage(MplGetCardToCardToken)

MplGetCardToCardTokenResponse = _reflection.GeneratedProtocolMessageType('MplGetCardToCardTokenResponse', (_message.Message,), dict(
  DESCRIPTOR = _MPLGETCARDTOCARDTOKENRESPONSE,
  __module__ = 'MplGetCardToCardToken_pb2'
  # @@protoc_insertion_point(class_scope:proto.MplGetCardToCardTokenResponse)
  ))
_sym_db.RegisterMessage(MplGetCardToCardTokenResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\032ProtoMplGetCardToCardToken'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: GeoGetNearbyCoordinate.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='GeoGetNearbyCoordinate.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x1cGeoGetNearbyCoordinate.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"S\n\x16GeoGetNearbyCoordinate\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x0b\n\x03lat\x18\x02 \x01(\x01\x12\x0b\n\x03lon\x18\x03 \x01(\x01\"\xcb\x01\n\x1eGeoGetNearbyCoordinateResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12<\n\x06result\x18\x02 \x03(\x0b\x32,.proto.GeoGetNearbyCoordinateResponse.Result\x1aH\n\x06Result\x12\x0f\n\x07user_id\x18\x01 \x01(\x04\x12\x13\n\x0bhas_comment\x18\x02 \x01(\x08\x12\x0b\n\x03lat\x18\x03 \x01(\x01\x12\x0b\n\x03lon\x18\x04 \x01(\x01\x42-\n\x0enet.iGap.protoB\x1bProtoGeoGetNearbyCoordinateb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_GEOGETNEARBYCOORDINATE = _descriptor.Descriptor(
  name='GeoGetNearbyCoordinate',
  full_name='proto.GeoGetNearbyCoordinate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.GeoGetNearbyCoordinate.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lat', full_name='proto.GeoGetNearbyCoordinate.lat', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lon', full_name='proto.GeoGetNearbyCoordinate.lon', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=70,
  serialized_end=153,
)


_GEOGETNEARBYCOORDINATERESPONSE_RESULT = _descriptor.Descriptor(
  name='Result',
  full_name='proto.GeoGetNearbyCoordinateResponse.Result',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='proto.GeoGetNearbyCoordinateResponse.Result.user_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='has_comment', full_name='proto.GeoGetNearbyCoordinateResponse.Result.has_comment', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lat', full_name='proto.GeoGetNearbyCoordinateResponse.Result.lat', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lon', full_name='proto.GeoGetNearbyCoordinateResponse.Result.lon', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=287,
  serialized_end=359,
)

_GEOGETNEARBYCOORDINATERESPONSE = _descriptor.Descriptor(
  name='GeoGetNearbyCoordinateResponse',
  full_name='proto.GeoGetNearbyCoordinateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.GeoGetNearbyCoordinateResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='result', full_name='proto.GeoGetNearbyCoordinateResponse.result', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_GEOGETNEARBYCOORDINATERESPONSE_RESULT, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=156,
  serialized_end=359,
)

_GEOGETNEARBYCOORDINATE.fields_by_name['request'].message_type = Request__pb2._REQUEST
_GEOGETNEARBYCOORDINATERESPONSE_RESULT.containing_type = _GEOGETNEARBYCOORDINATERESPONSE
_GEOGETNEARBYCOORDINATERESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_GEOGETNEARBYCOORDINATERESPONSE.fields_by_name['result'].message_type = _GEOGETNEARBYCOORDINATERESPONSE_RESULT
DESCRIPTOR.message_types_by_name['GeoGetNearbyCoordinate'] = _GEOGETNEARBYCOORDINATE
DESCRIPTOR.message_types_by_name['GeoGetNearbyCoordinateResponse'] = _GEOGETNEARBYCOORDINATERESPONSE

GeoGetNearbyCoordinate = _reflection.GeneratedProtocolMessageType('GeoGetNearbyCoordinate', (_message.Message,), dict(
  DESCRIPTOR = _GEOGETNEARBYCOORDINATE,
  __module__ = 'GeoGetNearbyCoordinate_pb2'
  # @@protoc_insertion_point(class_scope:proto.GeoGetNearbyCoordinate)
  ))
_sym_db.RegisterMessage(GeoGetNearbyCoordinate)

GeoGetNearbyCoordinateResponse = _reflection.GeneratedProtocolMessageType('GeoGetNearbyCoordinateResponse', (_message.Message,), dict(

  Result = _reflection.GeneratedProtocolMessageType('Result', (_message.Message,), dict(
    DESCRIPTOR = _GEOGETNEARBYCOORDINATERESPONSE_RESULT,
    __module__ = 'GeoGetNearbyCoordinate_pb2'
    # @@protoc_insertion_point(class_scope:proto.GeoGetNearbyCoordinateResponse.Result)
    ))
  ,
  DESCRIPTOR = _GEOGETNEARBYCOORDINATERESPONSE,
  __module__ = 'GeoGetNearbyCoordinate_pb2'
  # @@protoc_insertion_point(class_scope:proto.GeoGetNearbyCoordinateResponse)
  ))
_sym_db.RegisterMessage(GeoGetNearbyCoordinateResponse)
_sym_db.RegisterMessage(GeoGetNearbyCoordinateResponse.Result)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\033ProtoGeoGetNearbyCoordinate'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ClientCountRoomHistory.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ClientCountRoomHistory.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x1c\x43lientCountRoomHistory.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"J\n\x16\x43lientCountRoomHistory\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x0f\n\x07room_id\x18\x02 \x01(\x04\"\xb6\x01\n\x1e\x43lientCountRoomHistoryResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\r\n\x05media\x18\x02 \x01(\r\x12\r\n\x05image\x18\x03 \x01(\r\x12\r\n\x05video\x18\x04 \x01(\r\x12\r\n\x05\x61udio\x18\x05 \x01(\r\x12\r\n\x05voice\x18\x06 \x01(\r\x12\x0b\n\x03gif\x18\x07 \x01(\r\x12\x0c\n\x04\x66ile\x18\x08 \x01(\r\x12\x0b\n\x03url\x18\t \x01(\rB-\n\x0enet.iGap.protoB\x1bProtoClientCountRoomHistoryb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_CLIENTCOUNTROOMHISTORY = _descriptor.Descriptor(
  name='ClientCountRoomHistory',
  full_name='proto.ClientCountRoomHistory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.ClientCountRoomHistory.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='room_id', full_name='proto.ClientCountRoomHistory.room_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=70,
  serialized_end=144,
)


_CLIENTCOUNTROOMHISTORYRESPONSE = _descriptor.Descriptor(
  name='ClientCountRoomHistoryResponse',
  full_name='proto.ClientCountRoomHistoryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.ClientCountRoomHistoryResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='media', full_name='proto.ClientCountRoomHistoryResponse.media', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='image', full_name='proto.ClientCountRoomHistoryResponse.image', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='video', full_name='proto.ClientCountRoomHistoryResponse.video', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='audio', full_name='proto.ClientCountRoomHistoryResponse.audio', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='voice', full_name='proto.ClientCountRoomHistoryResponse.voice', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gif', full_name='proto.ClientCountRoomHistoryResponse.gif', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='file', full_name='proto.ClientCountRoomHistoryResponse.file', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='url', full_name='proto.ClientCountRoomHistoryResponse.url', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=147,
  serialized_end=329,
)

_CLIENTCOUNTROOMHISTORY.fields_by_name['request'].message_type = Request__pb2._REQUEST
_CLIENTCOUNTROOMHISTORYRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
DESCRIPTOR.message_types_by_name['ClientCountRoomHistory'] = _CLIENTCOUNTROOMHISTORY
DESCRIPTOR.message_types_by_name['ClientCountRoomHistoryResponse'] = _CLIENTCOUNTROOMHISTORYRESPONSE

ClientCountRoomHistory = _reflection.GeneratedProtocolMessageType('ClientCountRoomHistory', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTCOUNTROOMHISTORY,
  __module__ = 'ClientCountRoomHistory_pb2'
  # @@protoc_insertion_point(class_scope:proto.ClientCountRoomHistory)
  ))
_sym_db.RegisterMessage(ClientCountRoomHistory)

ClientCountRoomHistoryResponse = _reflection.GeneratedProtocolMessageType('ClientCountRoomHistoryResponse', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTCOUNTROOMHISTORYRESPONSE,
  __module__ = 'ClientCountRoomHistory_pb2'
  # @@protoc_insertion_point(class_scope:proto.ClientCountRoomHistoryResponse)
  ))
_sym_db.RegisterMessage(ClientCountRoomHistoryResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\033ProtoClientCountRoomHistory'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: UserRegister.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='UserRegister.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x12UserRegister.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"\x81\x02\n\x0cUserRegister\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x14\n\x0cphone_number\x18\x02 \x01(\x04\x12\x14\n\x0c\x63ountry_code\x18\x03 \x01(\t\x12?\n\x11preference_method\x18\x04 \x01(\x0e\x32$.proto.UserRegister.PreferenceMethod\x12\x0e\n\x06\x61pp_id\x18\x05 \x01(\r\"S\n\x10PreferenceMethod\x12\x14\n\x10VERIFY_CODE_AUTO\x10\x00\x12\x13\n\x0fVERIFY_CODE_SMS\x10\x01\x12\x14\n\x10VERIFY_CODE_CALL\x10\x02\"\x93\x03\n\x14UserRegisterResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x0f\n\x07user_id\x18\x03 \x01(\x04\x12\x13\n\x0b\x61uthor_hash\x18\x04 \x01(\t\x12\x32\n\x06method\x18\x05 \x01(\x0e\x32\".proto.UserRegisterResponse.Method\x12\x14\n\x0cresend_delay\x18\x06 \x01(\r\x12\x12\n\nsms_number\x18\x07 \x03(\x04\x12\x19\n\x11verify_code_regex\x18\x08 \x01(\t\x12\x1f\n\x17verify_code_digit_count\x18\t \x01(\r\x12\x1d\n\x15\x63\x61ll_method_supported\x18\n \x01(\x08\"g\n\x06Method\x12\x13\n\x0fVERIFY_CODE_SMS\x10\x00\x12\x16\n\x12VERIFY_CODE_SOCKET\x10\x01\x12\x1a\n\x16VERIFY_CODE_SMS_SOCKET\x10\x02\x12\x14\n\x10VERIFY_CODE_CALL\x10\x03\x42#\n\x0enet.iGap.protoB\x11ProtoUserRegisterb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_USERREGISTER_PREFERENCEMETHOD = _descriptor.EnumDescriptor(
  name='PreferenceMethod',
  full_name='proto.UserRegister.PreferenceMethod',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VERIFY_CODE_AUTO', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VERIFY_CODE_SMS', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VERIFY_CODE_CALL', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=235,
  serialized_end=318,
)
_sym_db.RegisterEnumDescriptor(_USERREGISTER_PREFERENCEMETHOD)

_USERREGISTERRESPONSE_METHOD = _descriptor.EnumDescriptor(
  name='Method',
  full_name='proto.UserRegisterResponse.Method',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VERIFY_CODE_SMS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VERIFY_CODE_SOCKET', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VERIFY_CODE_SMS_SOCKET', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VERIFY_CODE_CALL', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=621,
  serialized_end=724,
)
_sym_db.RegisterEnumDescriptor(_USERREGISTERRESPONSE_METHOD)


_USERREGISTER = _descriptor.Descriptor(
  name='UserRegister',
  full_name='proto.UserRegister',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.UserRegister.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='phone_number', full_name='proto.UserRegister.phone_number', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='country_code', full_name='proto.UserRegister.country_code', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='preference_method', full_name='proto.UserRegister.preference_method', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='proto.UserRegister.app_id', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _USERREGISTER_PREFERENCEMETHOD,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=61,
  serialized_end=318,
)


_USERREGISTERRESPONSE = _descriptor.Descriptor(
  name='UserRegisterResponse',
  full_name='proto.UserRegisterResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.UserRegisterResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='username', full_name='proto.UserRegisterResponse.username', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='proto.UserRegisterResponse.user_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='author_hash', full_name='proto.UserRegisterResponse.author_hash', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='method', full_name='proto.UserRegisterResponse.method', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='resend_delay', full_name='proto.UserRegisterResponse.resend_delay', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sms_number', full_name='proto.UserRegisterResponse.sms_number', index=6,
      number=7, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='verify_code_regex', full_name='proto.UserRegisterResponse.verify_code_regex', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='verify_code_digit_count', full_name='proto.UserRegisterResponse.verify_code_digit_count', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='call_method_supported', full_name='proto.UserRegisterResponse.call_method_supported', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _USERREGISTERRESPONSE_METHOD,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=321,
  serialized_end=724,
)

_USERREGISTER.fields_by_name['request'].message_type = Request__pb2._REQUEST
_USERREGISTER.fields_by_name['preference_method'].enum_type = _USERREGISTER_PREFERENCEMETHOD
_USERREGISTER_PREFERENCEMETHOD.containing_type = _USERREGISTER
_USERREGISTERRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_USERREGISTERRESPONSE.fields_by_name['method'].enum_type = _USERREGISTERRESPONSE_METHOD
_USERREGISTERRESPONSE_METHOD.containing_type = _USERREGISTERRESPONSE
DESCRIPTOR.message_types_by_name['UserRegister'] = _USERREGISTER
DESCRIPTOR.message_types_by_name['UserRegisterResponse'] = _USERREGISTERRESPONSE

UserRegister = _reflection.GeneratedProtocolMessageType('UserRegister', (_message.Message,), dict(
  DESCRIPTOR = _USERREGISTER,
  __module__ = 'UserRegister_pb2'
  # @@protoc_insertion_point(class_scope:proto.UserRegister)
  ))
_sym_db.RegisterMessage(UserRegister)

UserRegisterResponse = _reflection.GeneratedProtocolMessageType('UserRegisterResponse', (_message.Message,), dict(
  DESCRIPTOR = _USERREGISTERRESPONSE,
  __module__ = 'UserRegister_pb2'
  # @@protoc_insertion_point(class_scope:proto.UserRegisterResponse)
  ))
_sym_db.RegisterMessage(UserRegisterResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\021ProtoUserRegister'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ClientResolveUsername.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2
from ighap_bot.proto import Global_pb2 as Global__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ClientResolveUsername.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x1b\x43lientResolveUsername.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\x1a\x0cGlobal.proto\"J\n\x15\x43lientResolveUsername\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x10\n\x08username\x18\x02 \x01(\t\"\xd7\x01\n\x1d\x43lientResolveUsernameResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x37\n\x04type\x18\x02 \x01(\x0e\x32).proto.ClientResolveUsernameResponse.Type\x12#\n\x04user\x18\x03 \x01(\x0b\x32\x15.proto.RegisteredUser\x12\x19\n\x04room\x18\x04 \x01(\x0b\x32\x0b.proto.Room\"\x1a\n\x04Type\x12\x08\n\x04USER\x10\x00\x12\x08\n\x04ROOM\x10\x01\x42,\n\x0enet.iGap.protoB\x1aProtoClientResolveUsernameb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,Global__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_CLIENTRESOLVEUSERNAMERESPONSE_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='proto.ClientResolveUsernameResponse.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='USER', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ROOM', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=349,
  serialized_end=375,
)
_sym_db.RegisterEnumDescriptor(_CLIENTRESOLVEUSERNAMERESPONSE_TYPE)


_CLIENTRESOLVEUSERNAME = _descriptor.Descriptor(
  name='ClientResolveUsername',
  full_name='proto.ClientResolveUsername',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.ClientResolveUsername.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='username', full_name='proto.ClientResolveUsername.username', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=83,
  serialized_end=157,
)


_CLIENTRESOLVEUSERNAMERESPONSE = _descriptor.Descriptor(
  name='ClientResolveUsernameResponse',
  full_name='proto.ClientResolveUsernameResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.ClientResolveUsernameResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='proto.ClientResolveUsernameResponse.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='user', full_name='proto.ClientResolveUsernameResponse.user', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='room', full_name='proto.ClientResolveUsernameResponse.room', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CLIENTRESOLVEUSERNAMERESPONSE_TYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=160,
  serialized_end=375,
)

_CLIENTRESOLVEUSERNAME.fields_by_name['request'].message_type = Request__pb2._REQUEST
_CLIENTRESOLVEUSERNAMERESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_CLIENTRESOLVEUSERNAMERESPONSE.fields_by_name['type'].enum_type = _CLIENTRESOLVEUSERNAMERESPONSE_TYPE
_CLIENTRESOLVEUSERNAMERESPONSE.fields_by_name['user'].message_type = Global__pb2._REGISTEREDUSER
_CLIENTRESOLVEUSERNAMERESPONSE.fields_by_name['room'].message_type = Global__pb2._ROOM
_CLIENTRESOLVEUSERNAMERESPONSE_TYPE.containing_type = _CLIENTRESOLVEUSERNAMERESPONSE
DESCRIPTOR.message_types_by_name['ClientResolveUsername'] = _CLIENTRESOLVEUSERNAME
DESCRIPTOR.message_types_by_name['ClientResolveUsernameResponse'] = _CLIENTRESOLVEUSERNAMERESPONSE

ClientResolveUsername = _reflection.GeneratedProtocolMessageType('ClientResolveUsername', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTRESOLVEUSERNAME,
  __module__ = 'ClientResolveUsername_pb2'
  # @@protoc_insertion_point(class_scope:proto.ClientResolveUsername)
  ))
_sym_db.RegisterMessage(ClientResolveUsername)

ClientResolveUsernameResponse = _reflection.GeneratedProtocolMessageType('ClientResolveUsernameResponse', (_message.Message,), dict(
  DESCRIPTOR = _CLIENTRESOLVEUSERNAMERESPONSE,
  __module__ = 'ClientResolveUsername_pb2'
  # @@protoc_insertion_point(class_scope:proto.ClientResolveUsernameResponse)
  ))
_sym_db.RegisterMessage(ClientResolveUsernameResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\032ProtoClientResolveUsername'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: MplGetTopupToken.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='MplGetTopupToken.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x16MplGetTopupToken.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"\xfe\x01\n\x10MplGetTopupToken\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x1c\n\x14\x63harge_mobile_number\x18\x02 \x01(\x04\x12\x0e\n\x06\x61mount\x18\x03 \x01(\x04\x12*\n\x04type\x18\x04 \x01(\x0e\x32\x1c.proto.MplGetTopupToken.Type\"o\n\x04Type\x12\x14\n\x10IRANCELL_PREPAID\x10\x00\x12\x10\n\x0cIRANCELL_WOW\x10\x01\x12\x12\n\x0eIRANCELL_WIMAX\x10\x02\x12\x15\n\x11IRANCELL_POSTPAID\x10\x03\x12\x07\n\x03MCI\x10\x04\x12\x0b\n\x07RIGHTEL\x10\x05\"\x82\x01\n\x18MplGetTopupTokenResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x0e\n\x06status\x18\x02 \x01(\r\x12\r\n\x05token\x18\x03 \x01(\t\x12\x13\n\x0b\x65xpire_time\x18\x04 \x01(\r\x12\x0f\n\x07message\x18\x05 \x01(\tB\'\n\x0enet.iGap.protoB\x15ProtoMplGetTopupTokenb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_MPLGETTOPUPTOKEN_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='proto.MplGetTopupToken.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='IRANCELL_PREPAID', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IRANCELL_WOW', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IRANCELL_WIMAX', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IRANCELL_POSTPAID', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MCI', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RIGHTEL', index=5, number=5,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=208,
  serialized_end=319,
)
_sym_db.RegisterEnumDescriptor(_MPLGETTOPUPTOKEN_TYPE)


_MPLGETTOPUPTOKEN = _descriptor.Descriptor(
  name='MplGetTopupToken',
  full_name='proto.MplGetTopupToken',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.MplGetTopupToken.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='charge_mobile_number', full_name='proto.MplGetTopupToken.charge_mobile_number', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='amount', full_name='proto.MplGetTopupToken.amount', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='proto.MplGetTopupToken.type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MPLGETTOPUPTOKEN_TYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=65,
  serialized_end=319,
)


_MPLGETTOPUPTOKENRESPONSE = _descriptor.Descriptor(
  name='MplGetTopupTokenResponse',
  full_name='proto.MplGetTopupTokenResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.MplGetTopupTokenResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='proto.MplGetTopupTokenResponse.status', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='token', full_name='proto.MplGetTopupTokenResponse.token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='expire_time', full_name='proto.MplGetTopupTokenResponse.expire_time', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='proto.MplGetTopupTokenResponse.message', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=322,
  serialized_end=452,
)

_MPLGETTOPUPTOKEN.fields_by_name['request'].message_type = Request__pb2._REQUEST
_MPLGETTOPUPTOKEN.fields_by_name['type'].enum_type = _MPLGETTOPUPTOKEN_TYPE
_MPLGETTOPUPTOKEN_TYPE.containing_type = _MPLGETTOPUPTOKEN
_MPLGETTOPUPTOKENRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
DESCRIPTOR.message_types_by_name['MplGetTopupToken'] = _MPLGETTOPUPTOKEN
DESCRIPTOR.message_types_by_name['MplGetTopupTokenResponse'] = _MPLGETTOPUPTOKENRESPONSE

MplGetTopupToken = _reflection.GeneratedProtocolMessageType('MplGetTopupToken', (_message.Message,), dict(
  DESCRIPTOR = _MPLGETTOPUPTOKEN,
  __module__ = 'MplGetTopupToken_pb2'
  # @@protoc_insertion_point(class_scope:proto.MplGetTopupToken)
  ))
_sym_db.RegisterMessage(MplGetTopupToken)

MplGetTopupTokenResponse = _reflection.GeneratedProtocolMessageType('MplGetTopupTokenResponse', (_message.Message,), dict(
  DESCRIPTOR = _MPLGETTOPUPTOKENRESPONSE,
  __module__ = 'MplGetTopupToken_pb2'
  # @@protoc_insertion_point(class_scope:proto.MplGetTopupTokenResponse)
  ))
_sym_db.RegisterMessage(MplGetTopupTokenResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\025ProtoMplGetTopupToken'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: BillInquiryMci.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='BillInquiryMci.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x14\x42illInquiryMci.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"H\n\x0e\x42illInquiryMci\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x15\n\rmobile_number\x18\x02 \x01(\x04\"\xaf\x02\n\x16\x42illInquiryMciResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x0e\n\x06status\x18\x02 \x01(\r\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x38\n\x08mid_term\x18\x04 \x01(\x0b\x32&.proto.BillInquiryMciResponse.BillInfo\x12\x39\n\tlast_term\x18\x05 \x01(\x0b\x32&.proto.BillInquiryMciResponse.BillInfo\x1a\\\n\x08\x42illInfo\x12\x0e\n\x06status\x18\x01 \x01(\r\x12\x0f\n\x07\x62ill_id\x18\x02 \x01(\x04\x12\x0e\n\x06pay_id\x18\x03 \x01(\x04\x12\x0e\n\x06\x61mount\x18\x04 \x01(\x04\x12\x0f\n\x07message\x18\x05 \x01(\tB%\n\x0enet.iGap.protoB\x13ProtoBillInquiryMcib\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_BILLINQUIRYMCI = _descriptor.Descriptor(
  name='BillInquiryMci',
  full_name='proto.BillInquiryMci',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.BillInquiryMci.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='mobile_number', full_name='proto.BillInquiryMci.mobile_number', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=62,
  serialized_end=134,
)


_BILLINQUIRYMCIRESPONSE_BILLINFO = _descriptor.Descriptor(
  name='BillInfo',
  full_name='proto.BillInquiryMciResponse.BillInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='proto.BillInquiryMciResponse.BillInfo.status', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bill_id', full_name='proto.BillInquiryMciResponse.BillInfo.bill_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pay_id', full_name='proto.BillInquiryMciResponse.BillInfo.pay_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='amount', full_name='proto.BillInquiryMciResponse.BillInfo.amount', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='proto.BillInquiryMciResponse.BillInfo.message', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=348,
  serialized_end=440,
)

_BILLINQUIRYMCIRESPONSE = _descriptor.Descriptor(
  name='BillInquiryMciResponse',
  full_name='proto.BillInquiryMciResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.BillInquiryMciResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='proto.BillInquiryMciResponse.status', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='proto.BillInquiryMciResponse.message', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='mid_term', full_name='proto.BillInquiryMciResponse.mid_term', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_term', full_name='proto.BillInquiryMciResponse.last_term', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_BILLINQUIRYMCIRESPONSE_BILLINFO, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=137,
  serialized_end=440,
)

_BILLINQUIRYMCI.fields_by_name['request'].message_type = Request__pb2._REQUEST
_BILLINQUIRYMCIRESPONSE_BILLINFO.containing_type = _BILLINQUIRYMCIRESPONSE
_BILLINQUIRYMCIRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
_BILLINQUIRYMCIRESPONSE.fields_by_name['mid_term'].message_type = _BILLINQUIRYMCIRESPONSE_BILLINFO
_BILLINQUIRYMCIRESPONSE.fields_by_name['last_term'].message_type = _BILLINQUIRYMCIRESPONSE_BILLINFO
DESCRIPTOR.message_types_by_name['BillInquiryMci'] = _BILLINQUIRYMCI
DESCRIPTOR.message_types_by_name['BillInquiryMciResponse'] = _BILLINQUIRYMCIRESPONSE

BillInquiryMci = _reflection.GeneratedProtocolMessageType('BillInquiryMci', (_message.Message,), dict(
  DESCRIPTOR = _BILLINQUIRYMCI,
  __module__ = 'BillInquiryMci_pb2'
  # @@protoc_insertion_point(class_scope:proto.BillInquiryMci)
  ))
_sym_db.RegisterMessage(BillInquiryMci)

BillInquiryMciResponse = _reflection.GeneratedProtocolMessageType('BillInquiryMciResponse', (_message.Message,), dict(

  BillInfo = _reflection.GeneratedProtocolMessageType('BillInfo', (_message.Message,), dict(
    DESCRIPTOR = _BILLINQUIRYMCIRESPONSE_BILLINFO,
    __module__ = 'BillInquiryMci_pb2'
    # @@protoc_insertion_point(class_scope:proto.BillInquiryMciResponse.BillInfo)
    ))
  ,
  DESCRIPTOR = _BILLINQUIRYMCIRESPONSE,
  __module__ = 'BillInquiryMci_pb2'
  # @@protoc_insertion_point(class_scope:proto.BillInquiryMciResponse)
  ))
_sym_db.RegisterMessage(BillInquiryMciResponse)
_sym_db.RegisterMessage(BillInquiryMciResponse.BillInfo)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\023ProtoBillInquiryMci'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: SignalingCandidate.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Request_pb2 as Request__pb2
from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='SignalingCandidate.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x18SignalingCandidate.proto\x12\x05proto\x1a\rRequest.proto\x1a\x0eResponse.proto\"t\n\x12SignalingCandidate\x12\x1f\n\x07request\x18\x01 \x01(\x0b\x32\x0e.proto.Request\x12\x11\n\tcandidate\x18\x02 \x01(\t\x12\x10\n\x08sdp_m_id\x18\x03 \x01(\t\x12\x18\n\x10sdp_m_line_index\x18\x04 \x01(\r\"\x8d\x01\n\x1aSignalingCandidateResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\x16\n\x0epeer_candidate\x18\x02 \x01(\t\x12\x15\n\rpeer_sdp_m_id\x18\x03 \x01(\t\x12\x1d\n\x15peer_sdp_m_line_index\x18\x04 \x01(\rB)\n\x0enet.iGap.protoB\x17ProtoSignalingCandidateb\x06proto3')
  ,
  dependencies=[Request__pb2.DESCRIPTOR,Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_SIGNALINGCANDIDATE = _descriptor.Descriptor(
  name='SignalingCandidate',
  full_name='proto.SignalingCandidate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.SignalingCandidate.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='candidate', full_name='proto.SignalingCandidate.candidate', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sdp_m_id', full_name='proto.SignalingCandidate.sdp_m_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sdp_m_line_index', full_name='proto.SignalingCandidate.sdp_m_line_index', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=66,
  serialized_end=182,
)


_SIGNALINGCANDIDATERESPONSE = _descriptor.Descriptor(
  name='SignalingCandidateResponse',
  full_name='proto.SignalingCandidateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.SignalingCandidateResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='peer_candidate', full_name='proto.SignalingCandidateResponse.peer_candidate', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='peer_sdp_m_id', full_name='proto.SignalingCandidateResponse.peer_sdp_m_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='peer_sdp_m_line_index', full_name='proto.SignalingCandidateResponse.peer_sdp_m_line_index', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=185,
  serialized_end=326,
)

_SIGNALINGCANDIDATE.fields_by_name['request'].message_type = Request__pb2._REQUEST
_SIGNALINGCANDIDATERESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
DESCRIPTOR.message_types_by_name['SignalingCandidate'] = _SIGNALINGCANDIDATE
DESCRIPTOR.message_types_by_name['SignalingCandidateResponse'] = _SIGNALINGCANDIDATERESPONSE

SignalingCandidate = _reflection.GeneratedProtocolMessageType('SignalingCandidate', (_message.Message,), dict(
  DESCRIPTOR = _SIGNALINGCANDIDATE,
  __module__ = 'SignalingCandidate_pb2'
  # @@protoc_insertion_point(class_scope:proto.SignalingCandidate)
  ))
_sym_db.RegisterMessage(SignalingCandidate)

SignalingCandidateResponse = _reflection.GeneratedProtocolMessageType('SignalingCandidateResponse', (_message.Message,), dict(
  DESCRIPTOR = _SIGNALINGCANDIDATERESPONSE,
  __module__ = 'SignalingCandidate_pb2'
  # @@protoc_insertion_point(class_scope:proto.SignalingCandidateResponse)
  ))
_sym_db.RegisterMessage(SignalingCandidateResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\027ProtoSignalingCandidate'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: PushWalletPaymentVerified.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ighap_bot.proto import Response_pb2 as Response__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='PushWalletPaymentVerified.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x1fPushWalletPaymentVerified.proto\x12\x05proto\x1a\x0eResponse.proto\"U\n!PushWalletPaymentVerifiedResponse\x12!\n\x08response\x18\x01 \x01(\x0b\x32\x0f.proto.Response\x12\r\n\x05token\x18\x02 \x01(\tB0\n\x0enet.iGap.protoB\x1eProtoPushWalletPaymentVerifiedb\x06proto3')
  ,
  dependencies=[Response__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_PUSHWALLETPAYMENTVERIFIEDRESPONSE = _descriptor.Descriptor(
  name='PushWalletPaymentVerifiedResponse',
  full_name='proto.PushWalletPaymentVerifiedResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.PushWalletPaymentVerifiedResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='token', full_name='proto.PushWalletPaymentVerifiedResponse.token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=58,
  serialized_end=143,
)

_PUSHWALLETPAYMENTVERIFIEDRESPONSE.fields_by_name['response'].message_type = Response__pb2._RESPONSE
DESCRIPTOR.message_types_by_name['PushWalletPaymentVerifiedResponse'] = _PUSHWALLETPAYMENTVERIFIEDRESPONSE

PushWalletPaymentVerifiedResponse = _reflection.GeneratedProtocolMessageType('PushWalletPaymentVerifiedResponse', (_message.Message,), dict(
  DESCRIPTOR = _PUSHWALLETPAYMENTVERIFIEDRESPONSE,
  __module__ = 'PushWalletPaymentVerified_pb2'
  # @@protoc_insertion_point(class_scope:proto.PushWalletPaymentVerifiedResponse)
  ))
_sym_db.RegisterMessage(PushWalletPaymentVerifiedResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\016net.iGap.protoB\036ProtoPushWalletPaymentVerified'))
# @@protoc_insertion_point(module_scope)
